@@ -97,6 +97,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_eks
@@ -117,7 +119,7 @@ class KubeSphere(
         *,
         app_store: typing.Optional[builtins.bool] = None,
         cluster: typing.Optional[aws_cdk.aws_eks.ICluster] = None,
-        nodegroup_options: typing.Optional[aws_cdk.aws_eks.NodegroupOptions] = None,
+        nodegroup_options: typing.Optional[typing.Union[aws_cdk.aws_eks.NodegroupOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -126,6 +128,10 @@ class KubeSphere(
         :param cluster: The existing Amazon EKS cluster(if any). Default: - create a default new cluster
         :param nodegroup_options: Options to create the Amazon EKS managed nodegroup. Default: - 2x m5.large on-demand instances
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KubeSphere.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KubeSphereProps(
             app_store=app_store, cluster=cluster, nodegroup_options=nodegroup_options
         )
@@ -148,7 +154,7 @@ class KubeSphereProps:
         *,
         app_store: typing.Optional[builtins.bool] = None,
         cluster: typing.Optional[aws_cdk.aws_eks.ICluster] = None,
-        nodegroup_options: typing.Optional[aws_cdk.aws_eks.NodegroupOptions] = None,
+        nodegroup_options: typing.Optional[typing.Union[aws_cdk.aws_eks.NodegroupOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''The construct properties for KubeSphere.
 
@@ -157,7 +163,12 @@ class KubeSphereProps:
         :param nodegroup_options: Options to create the Amazon EKS managed nodegroup. Default: - 2x m5.large on-demand instances
         '''
         if isinstance(nodegroup_options, dict):
-            nodegroup_options = aws_cdk.aws_eks.NodegroupOptions(**nodegroup_options)
+            nodegroup_options = NodegroupOptions(**nodegroup_options)
+        if __debug__:
+            type_hints = typing.get_type_hints(KubeSphereProps.__init__)
+            check_type(argname="argument app_store", value=app_store, expected_type=type_hints["app_store"])
+            check_type(argname="argument cluster", value=cluster, expected_type=type_hints["cluster"])
+            check_type(argname="argument nodegroup_options", value=nodegroup_options, expected_type=type_hints["nodegroup_options"])
         self._values: typing.Dict[str, typing.Any] = {}
         if app_store is not None:
             self._values["app_store"] = app_store
